# workspace

[![Build Status](https://travis-ci.org/livingbio/workspace.svg?branch=master)](https://travis-ci.org/livingbio/workspace)
[![PyPI version](https://badge.fury.io/py/livingbio-workspace.svg)](https://badge.fury.io/py/livingbio-workspace)
